<?php

namespace Litepie\Medium\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Medium\Http\Requests\MediaDetailCategoryRequest;
use Litepie\Medium\Interfaces\MediaDetailCategoryRepositoryInterface;
use Litepie\Medium\Models\MediaDetailCategory;
use Litepie\Medium\Forms\MediaDetailCategory as Form;

/**
 * APIController  class for media_detail_category.
 */
class MediaDetailCategoryAPIController extends BaseController
{

    /**
     * Initialize media_detail_category resource controller.
     *
     * @param type MediaDetailCategoryRepositoryInterface $media_detail_category
     *
     * @return null
     */
    public function __construct(MediaDetailCategoryRepositoryInterface $media_detail_category)
    {
        parent::__construct();
        $this->repository = $media_detail_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Medium\Repositories\Criteria\MediaDetailCategoryResourceCriteria::class);
    }

    /**
     * Display a list of media_detail_category.
     *
     * @return Response
     */
    public function index(MediaDetailCategoryRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Medium\Repositories\Presenter\MediaDetailCategoryPresenter::class)
            ->paginate();
    }

    /**
     * Display media_detail_category.
     *
     * @param Request $request
     * @param Model   $media_detail_category
     *
     * @return Response
     */
    public function show(MediaDetailCategoryRequest $request, MediaDetailCategory $media_detail_category)
    {
        return $media_detail_category->setPresenter(\Litepie\Medium\Repositories\Presenter\MediaDetailCategoryListPresenter::class);
        ;
    }

    /**
     * Create new media_detail_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MediaDetailCategoryRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('medium::media_detail_category.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('medium/media_detail_category/' . $media_detail_category->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('medium/media_detail_category');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the media_detail_category.
     *
     * @param Request $request
     * @param Model   $media_detail_category
     *
     * @return Response
     */
    public function update(MediaDetailCategoryRequest $request, MediaDetailCategory $media_detail_category)
    {
        try {
            $data = $request->all();

            $media_detail_category->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('medium::media_detail_category.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('medium/media_detail_category/' . $media_detail_category->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('medium/media_detail_category/' . $media_detail_category->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the media_detail_category.
     *
     * @param Model   $media_detail_category
     *
     * @return Response
     */
    public function destroy(MediaDetailCategoryRequest $request, MediaDetailCategory $media_detail_category)
    {
        try {
            $media_detail_category->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('medium::media_detail_category.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('medium/media_detail_category/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('medium/media_detail_category/' . $media_detail_category->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
