<?php

namespace Litepie\Medium\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Medium\Models\MediaDetail;

class MediaDetailPolicy
{

    /**
     * Determine if the given user can view the media_detail.
     *
     * @param UserPolicy $user
     * @param MediaDetail $media_detail
     *
     * @return bool
     */
    public function view(UserPolicy $user, MediaDetail $media_detail)
    {
        if ($user->canDo('medium.media_detail.view') && $user->isAdmin()) {
            return true;
        }

        return $media_detail->user_id == user_id() && $media_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can create a media_detail.
     *
     * @param UserPolicy $user
     * @param MediaDetail $media_detail
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('medium.media_detail.create');
    }

    /**
     * Determine if the given user can update the given media_detail.
     *
     * @param UserPolicy $user
     * @param MediaDetail $media_detail
     *
     * @return bool
     */
    public function update(UserPolicy $user, MediaDetail $media_detail)
    {
        if ($user->canDo('medium.media_detail.edit') && $user->isAdmin()) {
            return true;
        }

        return $media_detail->user_id == user_id() && $media_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given media_detail.
     *
     * @param UserPolicy $user
     * @param MediaDetail $media_detail
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MediaDetail $media_detail)
    {
        return $media_detail->user_id == user_id() && $media_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given media_detail.
     *
     * @param UserPolicy $user
     * @param MediaDetail $media_detail
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MediaDetail $media_detail)
    {
        if ($user->canDo('medium.media_detail.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given media_detail.
     *
     * @param UserPolicy $user
     * @param MediaDetail $media_detail
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MediaDetail $media_detail)
    {
        if ($user->canDo('medium.media_detail.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
