<?php

namespace Litepie\Medium\Providers;

use Illuminate\Support\ServiceProvider;

class MediumServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'medium');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'medium');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerMedium();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerMedium()
    {
        $this->app->bind('medium', function($app) {
            return new Medium($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Medium', 'Lavalite\Medium\Facades\Medium');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litepie.medium', function ($app) {
            return $this->app->make('Litepie\Medium\Medium');
        });

        // Bind Media to repository
        $this->app->bind(
            'Litepie\Medium\Interfaces\MediaRepositoryInterface',
            \Litepie\Medium\Repositories\Eloquent\MediaRepository::class
        );        // Bind Brand to repository
        $this->app->bind(
            'Litepie\Medium\Interfaces\BrandRepositoryInterface',
            \Litepie\Medium\Repositories\Eloquent\BrandRepository::class
        );        // Bind MediaTag to repository
        $this->app->bind(
            'Litepie\Medium\Interfaces\MediaTagRepositoryInterface',
            \Litepie\Medium\Repositories\Eloquent\MediaTagRepository::class
        );        // Bind MediaTopic to repository
        $this->app->bind(
            'Litepie\Medium\Interfaces\MediaTopicRepositoryInterface',
            \Litepie\Medium\Repositories\Eloquent\MediaTopicRepository::class
        );        // Bind TargetGroup to repository
        $this->app->bind(
            'Litepie\Medium\Interfaces\TargetGroupRepositoryInterface',
            \Litepie\Medium\Repositories\Eloquent\TargetGroupRepository::class
        );        // Bind MediaDetail to repository
        $this->app->bind(
            'Litepie\Medium\Interfaces\MediaDetailRepositoryInterface',
            \Litepie\Medium\Repositories\Eloquent\MediaDetailRepository::class
        );        // Bind MediaDetailCategory to repository
        $this->app->bind(
            'Litepie\Medium\Interfaces\MediaDetailCategoryRepositoryInterface',
            \Litepie\Medium\Repositories\Eloquent\MediaDetailCategoryRepository::class
        );

        $this->app->register(\Litepie\Medium\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepie\Medium\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and medium's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepie.medium'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeMedium::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepie.medium'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepie/medium.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/medium')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/medium')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
